@@ -22,47 +22,76 @@
 
 #import "GtkApplicationDelegate.h"
 #include <gtk/gtk.h>
+#include <gmodule.h>
 #include "gtkosxapplication.h"
 
-static gchar *utf8_path = NULL;
-
 @implementation GtkApplicationDelegate
 
 -(void) applicationDidFinishLaunching: (NSNotification*)aNotification
 {
-  if (utf8_path != NULL)
-    {
-      GtkosxApplication *app = g_object_new (GTKOSX_TYPE_APPLICATION, NULL);
-      guint sig = g_signal_lookup ("NSApplicationOpenFile",
-				   GTKOSX_TYPE_APPLICATION);
-      gboolean result = FALSE;
-      if (sig)
-        {
-          g_signal_emit (app, sig, 0, utf8_path, &result);
-          g_free(utf8_path);
-          utf8_path = NULL;
-        }
-      g_object_unref (app);
-    }
 }
 
+#if MAC_OS_X_VERSION_MIN_REQUIRED >= 10130
+-(void) application: (NSApplication*)theApplication openURLs: (NSArray<NSURL *> *) urls
+{
+  gboolean overall_result = TRUE;
+  guint sig = g_signal_lookup ("NSApplicationOpenFile",
+                               GTKOSX_TYPE_APPLICATION);
+  if (sig)
+  {
+    GtkosxApplication *app = g_object_new (GTKOSX_TYPE_APPLICATION, NULL);
+    for (NSURL* url in urls)
+      {
+        gboolean result = TRUE;
+        g_signal_emit (app, sig, 0, [[url absoluteString] UTF8String], &result);
+        if (!result)
+          overall_result = FALSE;
+      }
+      [theApplication replyToOpenOrPrint: overall_result ? NSApplicationDelegateReplySuccess : NSApplicationDelegateReplyFailure];
+    g_object_unref (app);
+  }
+}
+#endif
+
+/* The openURLs documentation says that if the delegate implements it
+   then openFile won't be called, but that's not quite true: If the
+   odoc devent meets the criteria (it's a URL whose type is registered
+   in the app's CFBundleURLTypes and applicationDidFinishlaunching has
+   run) it calls openURLs otherwise it calls openFile or openFiles.
+ */
 -(BOOL) application: (NSApplication*)theApplication openFile: (NSString*) file
 {
-  utf8_path =  g_strdup([file UTF8String]);
   GtkosxApplication *app = g_object_new (GTKOSX_TYPE_APPLICATION, NULL);
   guint sig = g_signal_lookup ("NSApplicationOpenFile",
-			       GTKOSX_TYPE_APPLICATION);
+                               GTKOSX_TYPE_APPLICATION);
   gboolean result = FALSE;
   if (sig)
     {
-      g_signal_emit (app, sig, 0, utf8_path, &result);
-      g_free(utf8_path);
-      utf8_path = NULL;
+      g_signal_emit(app, sig, 0, [file UTF8String], &result);
     }
   g_object_unref (app);
   return result;
 }
 
+-(void) application: (NSApplication*)theApplication openFiless: (NSArray<NSString *> *) files
+{
+  gboolean overall_result = TRUE;
+  guint sig = g_signal_lookup ("NSApplicationOpenFile",
+                               GTKOSX_TYPE_APPLICATION);
+  if (sig)
+  {
+    GtkosxApplication *app = g_object_new (GTKOSX_TYPE_APPLICATION, NULL);
+    for (NSString *file in files)
+      {
+        gboolean result = TRUE;
+        g_signal_emit (app, sig, 0, [file UTF8String], &result);
+        if (!result)
+          overall_result = FALSE;
+      }
+      [theApplication replyToOpenOrPrint: overall_result ? NSApplicationDelegateReplySuccess : NSApplicationDelegateReplyFailure];
+    g_object_unref (app);
+  }
+}
 
 -(NSApplicationTerminateReply) applicationShouldTerminate: (NSApplication *)sender
 {
@@ -83,7 +112,6 @@ static gchar *utf8_path = NULL;
   if (!result)
     {
       g_object_unref (app);
-      g_free (utf8_path);
       return NSTerminateNow;
     }
   else
