@@ -21,6 +21,7 @@
  */
 
 #include <config.h>
+#include <gdk/gdkquartz.h> //for gdk_quartz_osx_version()
 #import <Cocoa/Cocoa.h>
 #include <gtk/gtk.h>
 #if GTK_MAJOR_VERSION == 3
@@ -123,11 +124,11 @@ cocoa_menu_item_update_checked (_GNSMenuItem *cocoa_item,
                 NULL);
 
   if (inconsistent)
-    [cocoa_item setState: NSMixedState];
+    [cocoa_item setState: GDK_QUARTZ_MIXED_STATE];
   else if (active)
-    [cocoa_item setState: NSOnState];
+    [cocoa_item setState: GDK_QUARTZ_ON_STATE];
   else
-    [cocoa_item setState: NSOffState];
+    [cocoa_item setState: GDK_QUARTZ_OFF_STATE];
 }
 
 static void
@@ -249,7 +250,7 @@ cocoa_menu_item_update_accelerator (_GNSMenuItem *cocoa_item,
 		  [cocoa_item setKeyEquivalent: @""];
                   return;
                 }
-              modifiers |= NSNumericPadKeyMask;
+              modifiers |= GDK_QUARTZ_NUMERIC_PAD_KEY_MASK;
             }
 
           /* if we somehow got here with GDK_A ... GDK_Z rather than GDK_a ... GDK_z, then take note
@@ -258,7 +259,7 @@ cocoa_menu_item_update_accelerator (_GNSMenuItem *cocoa_item,
 
           if (keyval_is_uppercase (actual_key))
             {
-              modifiers |= NSShiftKeyMask;
+              modifiers |= GDK_QUARTZ_SHIFT_KEY_MASK;
             }
 
           str = gdk_quartz_keyval_to_string (actual_key);
@@ -286,24 +287,24 @@ cocoa_menu_item_update_accelerator (_GNSMenuItem *cocoa_item,
             {
               if (key->accel_mods & GDK_SHIFT_MASK)
                 {
-                  modifiers |= NSShiftKeyMask;
+                  modifiers |= GDK_QUARTZ_SHIFT_KEY_MASK;
                 }
 
               if (key->accel_mods & GDK_CONTROL_MASK)
                 {
-                  modifiers |= NSControlKeyMask;
+                  modifiers |= GDK_QUARTZ_CONTROL_KEY_MASK;
                 }
 
               /* gdk/quartz maps Alt/Option to Mod5 */
               if (key->accel_mods & (GDK_MOD1_MASK))
                 {
-                  modifiers |= NSAlternateKeyMask;
+                  modifiers |= GDK_QUARTZ_ALTERNATE_KEY_MASK;
                 }
 
               /* gdk/quartz maps Command to MOD1 */
               if (key->accel_mods & GDK_META_MASK)
                 {
-                  modifiers |= NSCommandKeyMask;
+                  modifiers |= GDK_QUARTZ_COMMAND_KEY_MASK;
                 }
 
             }
