@@ -25,6 +25,7 @@
  */
 
 #include <gtk/gtk.h>
+#include <AvailabilityMacros.h>
 
 #import "GtkApplicationDelegate.h"
 #import "GtkApplicationNotify.h"
@@ -67,7 +68,8 @@ extern NSWindow* gdk_quartz_window_get_nswindow (GdkWindow*);
  * - Figure out what to do per app/window...
  *
  */
-G_DEFINE_TYPE (GtkosxApplication, gtkosx_application, G_TYPE_OBJECT)
+
+G_DEFINE_TYPE_WITH_PRIVATE (GtkosxApplication, gtkosx_application, G_TYPE_OBJECT)
 
 static GQuark emission_hook_quark = 0;
 
@@ -215,6 +217,12 @@ _nsapp_hide_others (id sender)
   [NSApp hideOtherApplications:sender];
 }
 
+static void
+_nsapp_quit (id sender)
+{
+  [NSApp terminate:nil];
+}
+
 /*
  * create_apple_menu:
  * @self: The GtkosxApplication object.
@@ -251,7 +259,7 @@ create_apple_menu (GtkosxApplication *self, GtkWidget *toplevel)
   NSString *title = [NSString stringWithUTF8String: _("Services")];
   NSMenu *menuServices = [[[NSMenu alloc] initWithTitle: title] autorelease];
   const char *appname = [get_application_name () UTF8String];
-  GClosure *hide_closure, *hide_others_closure;
+  GClosure *hide_closure, *hide_others_closure, *quit_closure;
   GtkAccelGroup *accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (toplevel), accel_group);
 
@@ -283,7 +291,7 @@ create_apple_menu (GtkosxApplication *self, GtkWidget *toplevel)
   /* Translators: This is the "Hide Others" menu item for the "Apple" menu. */
   menuitem = [[NSMenuItem alloc] initWithTitle: [NSString stringWithUTF8String: _("Hide Others")]
 	      action: @selector (hideOtherApplications: ) keyEquivalent: @"h"];
-  [menuitem setKeyEquivalentModifierMask: NSCommandKeyMask | NSAlternateKeyMask];
+  [menuitem setKeyEquivalentModifierMask: GDK_QUARTZ_COMMAND_KEY_MASK | GDK_QUARTZ_ALTERNATE_KEY_MASK];
   [menuitem setTarget: NSApp];
   [app_menu addItem: menuitem];
   [menuitem release];
@@ -305,6 +313,10 @@ create_apple_menu (GtkosxApplication *self, GtkWidget *toplevel)
    */
   menuitem = [[NSMenuItem alloc] initWithTitle: [NSString stringWithFormat: [NSString stringWithUTF8String: _("Quit %s")], appname]
 	      action: @selector (terminate:) keyEquivalent: @"q"];
+  quit_closure = g_cclosure_new (G_CALLBACK (_nsapp_quit),
+				 (void*)menuitem, NULL);
+  gtk_accel_group_connect (accel_group, GDK_q, GDK_META_MASK,
+			   GTK_ACCEL_MASK, quit_closure);
 /*
  * Accounts for the added application name to the Quit menu item in a
  * way that word order can be defined.
@@ -528,6 +540,7 @@ block_termination_accumulator (GSignalInvocationHint *ihint, GValue *accum,
  *
  * Returns: Whether to continue event processing.
  */
+
 static GdkFilterReturn
 global_event_filter_func (gpointer  windowing_event, GdkEvent *event,
                           gpointer  user_data)
@@ -547,8 +560,7 @@ global_event_filter_func (gpointer  windowing_event, GdkEvent *event,
    * thread; use an idle or timer event to start the handler if
    * necessary.
    */
-  if ([nsevent type] == NSKeyDown &&
-      gtkosx_application_use_quartz_accelerators (app) )
+  if ([nsevent type] == GDK_QUARTZ_KEY_DOWN && gtkosx_application_use_quartz_accelerators (app))
     {
       gboolean result;
 #if GTK_CHECK_VERSION (3, 6, 0)
@@ -585,7 +597,7 @@ static void
 gtkosx_application_init (GtkosxApplication *self)
 {
   [NSApplication sharedApplication];
-  self->priv = GTKOSX_APPLICATION_GET_PRIVATE (self);
+  self->priv = (GtkosxApplicationPrivate *) gtkosx_application_get_instance_private (self);
   self->priv->use_quartz_accelerators = TRUE;
   self->priv->dock_menu = NULL;
   gdk_window_add_filter (NULL, global_event_filter_func, (gpointer)self);
@@ -593,6 +605,7 @@ gtkosx_application_init (GtkosxApplication *self)
   [NSApp setDelegate: [GtkApplicationDelegate new]];
   self->priv->delegate = [NSApp delegate];
   bindtextdomain (PACKAGE_NAME, LOCALEDIR);
+  bind_textdomain_codeset(PACKAGE_NAME, "UTF-8");
 
   /* Check if we're running inside an application bundle and overwrite the
    * previously bound domain to a location inside the bundle.
@@ -632,7 +645,6 @@ void
 gtkosx_application_class_init (GtkosxApplicationClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-  g_type_class_add_private (klass, sizeof (GtkosxApplicationPrivate));
   gobject_class->constructor = gtkosx_application_constructor;
   /**
    * GtkosxApplication::NSApplicationDidBecomeActive:
@@ -714,10 +726,11 @@ gtkosx_application_class_init (GtkosxApplicationClass *klass)
    * @path: A UTF8-encoded file path to open.
    * @user_data: Data attached at connection
    *
-   * Emitted when a OpenFile, OpenFiles, or OpenEmptyFile event is
-   * received from the operating system. This signal does not implement
-   * drops, but it does implement "open with" events from Finder. An
-   * OpenEmptyFile is received at launch in Python applications.
+   * Emitted when an OpenFile, OpenFiles, or (in macOS 10.13 or later)
+   * OpenURLs event is received from the operating system. This signal
+   * does not implement drops, but it does implement "open with"
+   * events from Finder. If more than one file or URL is supplied then
+   * the signal is emitted once for each file.
    *
    * Returns: Boolean indicating success at opening the file.
    */
