@@ -65,6 +65,7 @@
 /* These others are optional */
 #define GTK_DISABLE_DEPRECATION_WARNINGS 1
 #define BUILT_UI //The built UI uses deprecated functions
+//#define GTKOSXAPPLICATION //Uses GtkMenuItems instead of GtkActions
 //#define QUARTZ_HANDLERS
 
 
@@ -546,14 +547,7 @@ app_will_quit_cb (GtkosxApplication *app, gpointer data)
 static gboolean
 app_open_file_cb (GtkosxApplication *app, gchar *path, gpointer user_data)
 {
-  GtkWindow *parent = GTK_WINDOW(user_data);
-  GtkWidget *dialog = gtk_message_dialog_new (parent,
-                                              GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              GTK_MESSAGE_INFO,
-                                              GTK_BUTTONS_CLOSE,
-                                              "File open event for %s", path);
-  gtk_dialog_run (GTK_DIALOG(dialog));
-  gtk_widget_destroy (dialog);
+  printf("Open file %s\n", path);
   return FALSE;
 }
 
